# E2E Testing Framework - Services
# ==================================
#
# This package contains service-specific test implementations.
# Each service has its own directory with:
#   - config.py: Service configuration
#   - data_schema.py: Pydantic models
#   - {service}_page.py: Page object
#   - modules/: Test modules
