"""
Version information for socialseed-e2e.

This module contains version information and metadata about the package.
"""

__version__ = "0.1.0"
__version_info__ = (0, 1, 0)
__author__ = "Dairon Pérez Frías"
__email__ = "dairon.perezfrias@gmail.com"
__license__ = "MIT"
__copyright__ = "Copyright 2026 Dairon Pérez Frías"
__url__ = "https://github.com/daironpf/socialseed-e2e"
__description__ = "Framework E2E para testing de APIs REST con Playwright"
__keywords__ = ["testing", "e2e", "api", "playwright", "rest", "framework"]

# Minimum supported Python version
__python_requires__ = ">=3.9"

# Playwright version compatibility
__playwright_version__ = ">=1.40.0"
